@@ -50,7 +50,6 @@
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <libgnomevfs/gnome-vfs-mime-info.h>
 #include <glib/gi18n-lib.h>
-#include <locale.h>
 #include <openbabel/mol.h>
 #include <openbabel/obconversion.h>
 #ifdef HAVE_FSTREAM
@@ -58,6 +57,7 @@
 #else
 #	include <fstream.h>
 #endif
+#include <clocale>
 
 // following code is needed to get file extensions, it as been essentially copied from gnome-vfs
 static map<string, list<string> > globs;
@@ -219,15 +219,10 @@ static Object* CreateFragment ()
 	return new gcpFragment ();
 }
 
-list<gcpApplication*> Apps;
 bool	gcpApplication::m_bInit = false;
 bool	gcpApplication::m_Have_Ghemical = false;
 bool	gcpApplication::m_Have_InChI = false;
 
-#warning "the following lines should be removed for stable releases"
-#undef PACKAGE
-#define PACKAGE "gchempaint-unstable" 
-
 static void on_config_changed (GConfClient *client, guint cnxn_id, GConfEntry *entry, gcpApplication *app)
 {
 	app->OnConfigChanged (client, cnxn_id, entry);
@@ -236,7 +231,6 @@ static void on_config_changed (GConfClient *client, guint cnxn_id, GConfEntry *e
 gcpApplication::gcpApplication ():
 	Application ("GChemPaint", DATADIR, PACKAGE, "gchempaint")
 {
-	Apps.push_back(this);
 	m_CurZ = 6;
 	m_pActiveDoc = NULL;
 	m_pActiveTool = NULL;
@@ -351,7 +345,7 @@ gcpApplication::gcpApplication ():
 	gcpTheme *pTheme;
 	m_Dummy = new Object (0);
 	for (j = Names.begin (); j != jend; j++) {
-		pTheme = ThemeManager.GetTheme (_("Default"));
+		pTheme = ThemeManager.GetTheme ("Default");
 		pTheme->AddClient (m_Dummy);
 	}
 }
@@ -362,7 +356,6 @@ gcpApplication::~gcpApplication()
 	for (; tool!= endtool; tool++)
 		delete (*tool).second;
 	Tools.clear ();
-	Apps.remove (this);
 	if (XmlDoc)
 		xmlFreeDoc (XmlDoc);
 	m_SupportedMimeTypes.clear ();
@@ -546,8 +539,8 @@ void gcpApplication::SaveWithBabel (string const &filename, const gchar *mime_ty
 	data.display_name = (char*) pDoc->GetTitle ();
 	data.description = NULL;
 	data.mime_type = (char*) mime_type;
-	data.app_name = "gchempaint";
-	data.app_exec = "gchempaint %u";
+	data.app_name = (char*) "gchempaint";
+	data.app_exec = (char*) "gchempaint %u";
 	data.groups = NULL;
 	data.is_private =  FALSE;
 	gtk_recent_manager_add_full (GetRecentManager (), filename.c_str (), &data);
@@ -647,8 +640,8 @@ void gcpApplication::OpenWithBabel (string const &filename, const gchar *mime_ty
 		data.display_name = (char*) pDoc->GetTitle ();
 		data.description = NULL;
 		data.mime_type = (char*) mime_type;
-		data.app_name = "gchempaint";
-		data.app_exec = "gchempaint %u";
+		data.app_name = (char*) "gchempaint";
+		data.app_exec = (char*) "gchempaint %u";
 		data.groups = NULL;
 		data.is_private =  FALSE;
 		gtk_recent_manager_add_full (GetRecentManager (), filename.c_str (), &data);
@@ -686,9 +679,9 @@ void gcpApplication::SaveGcp (string const &filename, gcpDocument* pDoc)
 	GtkRecentData data;
 	data.display_name = (char*) pDoc->GetTitle ();
 	data.description = NULL;
-	data.mime_type = "application/x-gchempaint";
-	data.app_name = "gchempaint";
-	data.app_exec = "gchempaint %u";
+	data.mime_type = (char*) "application/x-gchempaint";
+	data.app_name = (char*) "gchempaint";
+	data.app_exec = (char*) "gchempaint %u";
 	data.groups = NULL;
 	data.is_private =  FALSE;
 	gtk_recent_manager_add_full (GetRecentManager (), filename.c_str (), &data);
@@ -757,9 +750,9 @@ void gcpApplication::OpenGcp (string const &filename, gcpDocument* pDoc)
 		GtkRecentData data;
 		data.display_name = (char*) pDoc->GetTitle ();
 		data.description = NULL;
-		data.mime_type = "application/x-gchempaint";
-		data.app_name = "gchempaint";
-		data.app_exec = "gchempaint %u";
+		data.mime_type = (char*) "application/x-gchempaint";
+		data.app_name = (char*) "gchempaint";
+		data.app_exec = (char*) "gchempaint %u";
 		data.groups = NULL;
 		gtk_recent_manager_add_full (GetRecentManager (), filename.c_str (), &data);
 	}
