@@ -207,7 +207,7 @@ void gcpAtom::Update ()
 		m_Charge = 0;
 		m_ChargeAuto = false;
 	}
-	if (m_ChargeAutoPos) {
+	if (m_ChargeAutoPos && m_ChargePos != 0xff) {
 		NotifyPositionOccupation (m_ChargePos, false);
 		m_ChargePos = 0xff;
 	}
