@@ -1211,6 +1211,8 @@ void gcpDocument::SetTheme (gcpTheme *theme)
 	pango_attr_list_insert (m_PangoAttrList, pango_attr_weight_new (theme->GetFontWeight ()));
 	pango_attr_list_insert (m_PangoAttrList, pango_attr_stretch_new (theme->GetFontStretch ()));
 	pango_attr_list_insert (m_PangoAttrList, pango_attr_variant_new (theme->GetFontVariant ()));
+	if (m_pView)
+		m_pView->UpdateTheme ();
 }
 
 bool gcpDocument::OnSignal (SignalId Signal, Object *Child)
@@ -1291,6 +1293,10 @@ double gcpDocument::GetMedianBondLength ()
 		}
 	}
 	if (nb > 0)
+#ifdef HAVE_VECTOR_DATA
 		go_range_median_inter_nonconst (lengths.data (), nb, &result);
+#else
+		go_range_median_inter_nonconst (&(*lengths.begin ()), nb, &result);
+#endif
 	return result;
 }
