@@ -49,7 +49,7 @@ static void on_string_clear_data(GtkClipboard *clipboard, gcpStringDlg *dlg)
 {
 }
 
-gcpStringDlg::gcpStringDlg (gcpDocument *pDoc, string& data, enum data_type type): Dialog (pDoc->GetApplication(), DATADIR"/gchempaint/ui/stringdlg.glade", "string")
+gcpStringDlg::gcpStringDlg (gcpDocument *pDoc, string& data, enum data_type type): Dialog (pDoc->GetApplication(), GLADEDIR"/stringdlg.glade", "string")
 {
 	Data = data;
 	Type = type;
