@@ -2,7 +2,7 @@
  * GChemPaint library
  * window.cc
  *
- * Copyright (C) 2006 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2006-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -23,25 +23,40 @@
 #include "gchempaint-config.h"
 #include "application.h"
 #include "document.h"
+#include "newfiledlg.h"
 #include "window.h"
 #include "about.h"
+#include "preferences.h"
+#include "theme.h"
 #include "zoomdlg.h"
 #include <gcu/filechooser.h>
 #include <libgnomeprint/gnome-print.h>
 #include <libgnomeprint/gnome-print-job.h>
 #include <libgnomeprintui/gnome-print-dialog.h>
 #include <libgnomeprintui/gnome-print-job-preview.h>
+#include <glib/gi18n-lib.h>
 
 static void on_destroy (GtkWidget* widget, gcpWindow* Win)
 {
+	Win->GetDocument ()->GetView ()->PrepareUnselect ();
 	delete Win;
 }
 
+static bool on_delete_event (GtkWidget* widget, GdkEvent *event, gcpWindow* Win)
+{
+	return !Win->VerifySaved ();
+}
+
 static void on_file_new(GtkWidget* widget, gcpWindow* Win)
 {
 	Win->OnFileNew();
 }
 
+static void on_themed_file_new(GtkWidget* widget, gcpWindow* Win)
+{
+	new gcpNewFileDlg (Win->GetApplication ());
+}
+
 static void on_file_open(GtkWidget* widget, gcpWindow* Win)
 {
 	Win->OnFileOpen();
@@ -117,6 +132,11 @@ static void on_delete_selection(GtkWidget* widget, gcpWindow* Win)
 	Win->OnDeleteSelection();
 }
 
+static void on_preferences (GtkWidget* widget, gcpWindow* Win)
+{
+	Win->OnPreferences ();
+}
+
 /*static bool on_key_release(GtkWidget* widget, GdkEventKey* ev, gcpWindow* Win)
 {
 	return Win->OnKeyReleased(widget, ev);
@@ -181,23 +201,25 @@ static void on_zoom (GtkWidget* widget, gcpWindow* Win)
 
 static bool on_focus_in (GtkWidget *widget, GdkEventFocus *event, gcpWindow* Win)
 {
+	Win->GetDocument ()->GetView ()->ShowCursor (true);
 	gcpApplication *App = Win->GetApplication ();
 	App->NotifyFocus (true, Win);
 	gtk_clipboard_request_contents (gtk_clipboard_get (GDK_SELECTION_CLIPBOARD), gdk_atom_intern ("TARGETS", FALSE),  (GtkClipboardReceivedFunc) on_receive_targets, App);
-	return false;
+	return true;
 }
 
 static bool on_focus_out (GtkWidget *widget, GdkEventFocus *event, gcpWindow* Win)
 {
+	Win->GetDocument ()->GetView ()->ShowCursor (false);
 	Win->GetApplication ()->NotifyFocus (false);
-	return false;
+	return true;
 }
 
 static bool on_state (GtkWidget *widget, GdkEventWindowState *event, gcpWindow* Win)
 {
 	if (event->changed_mask & GDK_WINDOW_STATE_ICONIFIED)
 		Win->GetApplication ()->NotifyIconification (event->new_window_state & GDK_WINDOW_STATE_ICONIFIED);
-	return false;
+	return true;
 }
 
 static void on_help (GtkWidget *widget, gcpWindow* Win)
@@ -207,12 +229,12 @@ static void on_help (GtkWidget *widget, gcpWindow* Win)
 
 static void on_web (GtkWidget *widget, gcpWindow* Win)
 {
-	Win->GetApplication ()->OnWeb ();
+	Win->GetApplication ()->OnWeb ((char*) "gchempaint.nongnu.org");
 }
 
 static void on_mail (GtkWidget *widget, gcpWindow* Win)
 {
-	Win->GetApplication ()->OnMail ();
+	Win->GetApplication ()->OnMail ((char*) "mailto:gchempaint-main@nongnu.org");
 }
 
 static void on_bug (GtkWidget *widget, gcpWindow* Win)
@@ -269,6 +291,15 @@ static bool on_key_press(GtkWidget* widget, GdkEventKey* ev, gcpWindow* Win)
 	return Win->OnKeyPressed(widget, ev);
 }
 
+static void on_recent (GtkRecentChooser *widget, gcpWindow *Win)
+{
+	gcpApplication *App = Win->GetApplication ();
+	GtkRecentInfo *info = gtk_recent_chooser_get_current_item (widget);
+	gcpDocument *pDoc = Win->GetDocument ();
+	App->FileProcess (gtk_recent_info_get_uri (info), gtk_recent_info_get_mime_type (info), false, NULL, (!pDoc->HasChildren () && !pDoc->GetDirty ())? pDoc: NULL);
+	gtk_recent_info_unref (info);
+}
+
 /*********
  * Menus *
  *********/
@@ -276,6 +307,8 @@ static GtkActionEntry entries[] = {
   { "FileMenu", NULL, N_("_File") },
 	  { "New", GTK_STOCK_NEW, N_("_New File"), NULL,
 		  N_("Create a new file"), G_CALLBACK (on_file_new) },
+	  { "NewThemed", GTK_STOCK_NEW, N_("Ne_w File with Theme..."), "<shift><control>N",
+		  N_("Create a new file using a theme"), G_CALLBACK (on_themed_file_new) },
 	  { "Open", GTK_STOCK_OPEN, N_("_Open..."), "<control>O",
 		  N_("Open a file"), G_CALLBACK (on_file_open) },
 	  { "Save", GTK_STOCK_SAVE, N_("_Save"), "<control>S",
@@ -303,10 +336,12 @@ static GtkActionEntry entries[] = {
 		  N_("Copy the selection"), G_CALLBACK (on_copy_selection) },
 	  { "Paste", GTK_STOCK_PASTE, N_("_Paste"), "<control>V",
 		  N_("Paste the clipboard"), G_CALLBACK (on_paste_selection) },
-	  { "Delete", GTK_STOCK_CLEAR, N_("C_lear"), NULL,
+	  { "Erase", GTK_STOCK_CLEAR, N_("C_lear"), NULL,
 		  N_("Clear the selection"), G_CALLBACK (on_delete_selection) },
 	  { "SelectAll", NULL, N_("Select _All"), "<control>A",
 		  N_("Select everything"), G_CALLBACK (on_select_all) },
+	  { "Preferences", GTK_STOCK_PREFERENCES, N_("Pr_eferences..."), NULL,
+		  N_("Configure the application"), G_CALLBACK (on_preferences) },
   { "ViewMenu", NULL, N_("_View") },
 	  { "ZoomMenu", NULL, N_("_Zoom") },
 		  { "400%", NULL, N_("_400%"), "<control>4",
@@ -350,6 +385,7 @@ static const char *ui_description =
 "  <menubar name='MainMenu'>"
 "    <menu action='FileMenu'>"
 "      <menuitem action='New'/>"
+"      <menuitem action='NewThemed'/>"
 "      <menuitem action='Open'/>"
 "      <menuitem action='Save'/>"
 "      <menuitem action='SaveAs'/>"
@@ -369,9 +405,11 @@ static const char *ui_description =
 "      <menuitem action='Cut'/>"
 "      <menuitem action='Copy'/>"
 "      <menuitem action='Paste'/>"
-"      <menuitem action='Delete'/>"
+"      <menuitem action='Erase'/>"
 "      <separator name='edit-sep2'/>"
 "      <menuitem action='SelectAll'/>"
+"      <separator name='edit-sep3'/>"
+"      <menuitem action='Preferences'/>"
 "    </menu>"
 "    <menu action='ViewMenu'>"
 "      <menu action='ZoomMenu'>"
@@ -433,7 +471,7 @@ static const char *ui_web_description =
 "  </menubar>"
 "</ui>";
 
-gcpWindow::gcpWindow (gcpApplication *App, char const *extra_ui)
+gcpWindow::gcpWindow (gcpApplication *App, char const *Theme, char const *extra_ui)
 {
 	GtkWidget *vbox;
 	GtkWidget *bar;
@@ -442,14 +480,11 @@ gcpWindow::gcpWindow (gcpApplication *App, char const *extra_ui)
 	GError *error;
 
 	m_App = App;
-	m_Doc = new gcpDocument (App, true, this);
-	GtkWidget *w = m_Doc->GetView ()->CreateNewWidget ();
 	m_Window = GTK_WINDOW (gtk_window_new (GTK_WINDOW_TOPLEVEL));
+	g_object_set (G_OBJECT (m_Window), "urgency-hint", false, NULL);
 	g_object_set_data (G_OBJECT (m_Window), "gcp-role", (void*) 1);
-	gtk_window_set_position (m_Window, GTK_WIN_POS_MOUSE);
-	gtk_window_set_title (m_Window, m_Doc->GetTitle ());
-	gtk_window_set_icon_name (m_Window, "gchempaint");
 	g_signal_connect (G_OBJECT (m_Window), "destroy", G_CALLBACK (on_destroy), this);
+	g_signal_connect (G_OBJECT (m_Window), "delete-event", G_CALLBACK (on_delete_event), this);
 	g_signal_connect (G_OBJECT (m_Window), "focus_in_event", G_CALLBACK (on_focus_in), this);
 	g_signal_connect (G_OBJECT (m_Window), "focus_out_event", G_CALLBACK (on_focus_out), this);
 	g_signal_connect (G_OBJECT (m_Window), "window-state-event", G_CALLBACK (on_state), this);
@@ -489,18 +524,38 @@ gcpWindow::gcpWindow (gcpApplication *App, char const *extra_ui)
 		g_error_free (error);
 	}
 
+	GtkWidget *menu = gtk_ui_manager_get_widget (m_UIManager, "/MainMenu/FileMenu/Open");
+	GtkWidget *w = gtk_recent_chooser_menu_new_for_manager (App->GetRecentManager ());
+	GtkRecentFilter *filter = gtk_recent_filter_new ();
+	gtk_recent_filter_add_mime_type (filter, "application/x-gchempaint");
+	gtk_recent_filter_add_mime_type (filter, "chemical/x-chemdraw");
+	gtk_recent_filter_add_mime_type (filter, "chemical/x-cml");
+	gtk_recent_filter_add_mime_type (filter, "chemical/x-mdl-molfile");
+	gtk_recent_filter_add_mime_type (filter, "chemical/x-pdb");
+	gtk_recent_chooser_add_filter (GTK_RECENT_CHOOSER (w), filter);
+	g_signal_connect (G_OBJECT (w), "item-activated", G_CALLBACK (on_recent), this);
+	GtkWidget *item = gtk_menu_item_new_with_mnemonic (_("Open _recent"));
+	gtk_menu_item_set_submenu (GTK_MENU_ITEM (item), w);
+	gtk_widget_show_all (item);
+	gtk_menu_shell_insert (GTK_MENU_SHELL (gtk_widget_get_parent (menu)), item, 3);
+
 	bar = gtk_ui_manager_get_widget (m_UIManager, "/MainMenu");
 	gtk_box_pack_start (GTK_BOX (vbox), bar, false, false, 0);
 	bar = gtk_ui_manager_get_widget (m_UIManager, "/MainToolbar");
 	gtk_toolbar_set_tooltips(GTK_TOOLBAR(bar), true);
-	gtk_box_pack_start (GTK_BOX (vbox), bar, true, true, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), bar, false, false, 0);
+	m_Doc = new gcpDocument (App, true, this);
+	if (Theme)
+		m_Doc->SetTheme (ThemeManager.GetTheme (Theme));
+	gtk_window_set_title (m_Window, m_Doc->GetTitle ());
+	w = m_Doc->GetView ()->CreateNewWidget ();
 	GtkScrolledWindow* scroll = (GtkScrolledWindow*)gtk_scrolled_window_new(NULL, NULL);
 	gtk_scrolled_window_set_policy(scroll, GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_shadow_type (scroll, GTK_SHADOW_IN);
 	gtk_scrolled_window_add_with_viewport(scroll, w);
 	gtk_widget_set_size_request(GTK_WIDGET(scroll), 408, 308);
 	gtk_widget_show(GTK_WIDGET(scroll));
-	gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (scroll), false, false, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (scroll), true, true, 0);
 	m_Bar = gtk_statusbar_new ();
 	m_statusId = gtk_statusbar_get_context_id (GTK_STATUSBAR (m_Bar), "status");
 	gtk_statusbar_push (GTK_STATUSBAR (m_Bar), m_statusId, _("Ready"));
@@ -510,6 +565,9 @@ gcpWindow::gcpWindow (gcpApplication *App, char const *extra_ui)
 	g_signal_connect(GTK_OBJECT(m_Window), "key_press_event", (GCallback)on_key_press, this);
 	g_signal_connect(GTK_OBJECT(m_Window), "key_release_event", (GCallback)on_key_release, this);
 
+	gtk_widget_set_sensitive (gtk_ui_manager_get_widget (m_UIManager, "/MainMenu/EditMenu/Copy"), false);
+	gtk_widget_set_sensitive (gtk_ui_manager_get_widget (m_UIManager, "/MainMenu/EditMenu/Cut"), false);
+	gtk_widget_set_sensitive (gtk_ui_manager_get_widget (m_UIManager, "/MainMenu/EditMenu/Erase"), false);
 	gtk_widget_show_all (GTK_WIDGET (m_Window));
 	App->SetActiveDocument (m_Doc);
 }
@@ -534,7 +592,7 @@ void gcpWindow::OnSave()
 
 void gcpWindow::OnFileOpen()
 {
-	FileChooser (m_App, false, m_App->GetSupportedMimeTypes (), (!m_Doc->HasChildren () && !m_Doc->IsDirty ())? m_Doc: NULL);
+	FileChooser (m_App, false, m_App->GetSupportedMimeTypes (), (!m_Doc->HasChildren () && !m_Doc->GetDirty ())? m_Doc: NULL);
 }
 
 void gcpWindow::OnProperties()
@@ -588,10 +646,6 @@ void gcpWindow::SetActive (gcpDocument* pDoc, GtkWidget* w)
 {
 }
 
-void gcpWindow::OnFileClose ()
-{
-}
-
 void gcpWindow::OnUndo()
 {
 	m_Doc->OnUndo();
@@ -638,6 +692,11 @@ void gcpWindow::OnDeleteSelection()
 		m_Doc->GetView ()->OnDeleteSelection (m_Doc->GetWidget ());
 }
 
+void gcpWindow::OnPreferences ()
+{
+	new gcpPrefsDlg (GetApplication ());
+}
+
 void gcpWindow::Zoom (double zoom)
 {
 	gcpView *pView = m_Doc->GetView ();
@@ -645,11 +704,11 @@ void gcpWindow::Zoom (double zoom)
 	if (zoom >= 0.2 && zoom <= 8.)
 		pView->Zoom (zoom);
 	else {
-		Dialog *pDialog = GetApplication ()->GetDialog ("Zoom");
+		Dialog *pDialog = m_Doc->GetDialog ("Zoom");
 		if (pDialog)
 			gtk_window_present (pDialog->GetWindow ()); 
 		else
-			new gcpZoomDlg (GetApplication ());
+			new gcpZoomDlg (m_Doc);
 	}
 }
 
@@ -697,10 +756,14 @@ bool gcpWindow::OnKeyReleased(GtkWidget* widget, GdkEventKey* ev)
 		false;
 }
 
-void gcpWindow::Close ()
+bool gcpWindow::Close ()
 {
-	m_Doc->GetView ()->PrepareUnselect ();
-	gtk_widget_destroy (GTK_WIDGET (m_Window));
+	if (VerifySaved ()) {
+		m_Doc->GetView ()->PrepareUnselect ();
+		gtk_widget_destroy (GTK_WIDGET (m_Window));
+		return true;
+	}
+	return false;
 }
 
 
@@ -708,3 +771,31 @@ char const *gcpWindow::GetDefaultTitle ()
 {
 	return _("GChemPaint");
 }
+
+void gcpWindow::ActivateActionWidget (char const *path, bool activate)
+{
+	GtkWidget *w = gtk_ui_manager_get_widget (m_UIManager, path);
+	if (w)
+		gtk_widget_set_sensitive (w, activate);
+}
+
+bool gcpWindow::VerifySaved ()
+{
+	if (!m_Doc->GetDirty ())
+		return true;
+	gchar* str = g_strdup_printf(_("\"%s\" has been modified.  Do you wish to save it?"), m_Doc->GetTitle ());
+	GtkWidget* mbox;
+	int res;
+	do {
+		mbox = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, str);
+		gtk_dialog_add_button (GTK_DIALOG (mbox),  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+		res = gtk_dialog_run (GTK_DIALOG (mbox));
+		gtk_widget_destroy (mbox);
+		if (res == GTK_RESPONSE_YES)
+			OnSave ();
+	} while ((res == GTK_RESPONSE_YES) && (m_Doc->GetFileName () == NULL));
+	if (res == GTK_RESPONSE_NO)
+		m_Doc->SetDirty (false);
+	g_free(str);
+	return (res != GTK_RESPONSE_CANCEL);
+}
