@@ -4,7 +4,7 @@
  * GChemPaint arrows plugin
  * retrosynthesis.cc
  *
- * Copyright (C) 2004-2006 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -22,6 +22,7 @@
  * USA
  */
 
+#include "gchempaint-config.h"
 #include "retrosynthesis.h"
 #include "retrosynthesisarrow.h"
 #include "retrosynthesisstep.h"
@@ -29,13 +30,14 @@
 #include "lib/theme.h"
 #include "lib/widgetdata.h"
 #include "lib/view.h"
-#include <math.h>
+#include <glib/gi18n-lib.h>
+#include <cmath>
 
 TypeId RetrosynthesisType = NoType;
 
 gcpRetrosynthesis::gcpRetrosynthesis (): Object (RetrosynthesisType)
 {
-	SetId ("rsy1");
+	SetId ((char*) "rsy1");
 	Target = NULL;
 }
 
@@ -121,17 +123,6 @@ bool gcpRetrosynthesis::Load (xmlNodePtr node)
 	return true;
 }
 
-void gcpRetrosynthesis::Add (GtkWidget* w)
-{
-	map<string, Object*>::iterator i;
-	Object* p = GetFirstChild (i);
-	while (p)
-	{
-		p->Add (w);
-		p = GetNextChild (i);
-	}
-}
-
 typedef struct
 {
 	double x, y;
@@ -289,8 +280,8 @@ int gcpRetrosynthesis::Validate (bool split)
 			return 2;
 		pObj = GetFirstChild (i);
 		while (pObj && (pObj->GetType () != RetrosynthesisStepType || 
-			(reinterpret_cast<gcpRetrosynthesisStep *> (pObj))->GetArrow ()) ||
-			pObj == Target)
+			(reinterpret_cast<gcpRetrosynthesisStep *> (pObj))->GetArrow () ||
+			pObj == Target))
 			pObj = GetNextChild (i);
 		if (reinterpret_cast<gcpRetrosynthesisStep *> (pObj)->Validate ()) {
 			gcpRetrosynthesis *rs = new gcpRetrosynthesis (GetParent (), 
@@ -333,15 +324,15 @@ static void AlignStep (map<Object*, StepData> &data, gcpRetrosynthesisStep *step
 			horiz = false;
 		if (horiz) {
 			if (x > 0)
-				dx = sd.r.x1 - sd.x + pTheme->GetArrowPadding () * pTheme->GetZoomFactor ();
+				dx = sd.r.x1 - sd.x + pTheme->GetArrowPadding ();
 			else
-				dx = sd.r.x0 - sd.x - pTheme->GetArrowPadding () * pTheme->GetZoomFactor ();
+				dx = sd.r.x0 - sd.x - pTheme->GetArrowPadding ();
 			dy = dx * y / x;
 		} else {
 			if (y > 0)
-				dy = sd.r.y1 - sd.y + pTheme->GetArrowPadding () * pTheme->GetZoomFactor ();
+				dy = sd.r.y1 - sd.y + pTheme->GetArrowPadding ();
 			else
-				dy = sd.r.y0 - sd.y - pTheme->GetArrowPadding () * pTheme->GetZoomFactor ();
+				dy = sd.r.y0 - sd.y - pTheme->GetArrowPadding ();
 			dx = dy * x / y;
 		}
 		x1 += x0 = (dx + sd.x) / pTheme->GetZoomFactor () - x0;
@@ -351,15 +342,15 @@ static void AlignStep (map<Object*, StepData> &data, gcpRetrosynthesisStep *step
 		sd1 = data[(*i).first];
 		if (horiz) {
 			if (x > 0)
-				dx = sd1.x - sd1.r.x0 + pTheme->GetArrowPadding () * pTheme->GetZoomFactor ();
+				dx = sd1.x - sd1.r.x0 + pTheme->GetArrowPadding ();
 			else
-				dx = sd1.x - sd1.r.x1 +- pTheme->GetArrowPadding () * pTheme->GetZoomFactor ();
+				dx = sd1.x - sd1.r.x1 +- pTheme->GetArrowPadding ();
 			dy = dx * y / x;
 		} else {
 			if (y > 0)
-				dy = sd1.y - sd1.r.y0 + pTheme->GetArrowPadding () * pTheme->GetZoomFactor ();
+				dy = sd1.y - sd1.r.y0 + pTheme->GetArrowPadding ();
 			else
-				dy = sd1.y - sd1.r.y1 - pTheme->GetArrowPadding () * pTheme->GetZoomFactor ();
+				dy = sd1.y - sd1.r.y1 - pTheme->GetArrowPadding ();
 			dx = dy * x / y;
 		}
 		dx = x1 * pTheme->GetZoomFactor () - (sd1.x - dx);
@@ -421,7 +412,7 @@ static void do_destroy_retrosynthesis (void *data)
 	pDoc->FinishOperation ();
 }
 
-bool gcpRetrosynthesis::BuildContextualMenu (GtkUIManager *UIManager, Object *object)
+bool gcpRetrosynthesis::BuildContextualMenu (GtkUIManager *UIManager, Object *object, double x, double y)
 {
 	GtkActionGroup *group = gtk_action_group_new ("retrosynthesis");
 	GtkAction *action = gtk_action_new ("destroy-rs", _("Destroy the retrosynthesis path"), NULL, NULL);
@@ -431,7 +422,7 @@ bool gcpRetrosynthesis::BuildContextualMenu (GtkUIManager *UIManager, Object *ob
 	gtk_ui_manager_add_ui_from_string (UIManager, buf, -1, NULL);
 	GtkWidget *w = gtk_ui_manager_get_widget (UIManager, "/popup/destroy-rs");
 	g_signal_connect_swapped (w, "activate", G_CALLBACK (do_destroy_retrosynthesis), this);
-	GetParent ()->BuildContextualMenu (UIManager, object);
+	GetParent ()->BuildContextualMenu (UIManager, object, x, y);
 	return true;
 }
 
@@ -446,7 +437,7 @@ bool gcpRetrosynthesis::OnSignal (SignalId Signal, Object *Child)
 
 gcpRetrosynthesis::gcpRetrosynthesis (Object* parent, gcpRetrosynthesisStep *step): Object (RetrosynthesisType)
 {
-	SetId ("rsy1");
+	SetId ((char*) "rsy1");
 	SetParent (parent);
 	Target = step;
 	AddChild (Target);
