@@ -4,9 +4,7 @@
  * GChemPaint atoms plugin
  * elementtool.h 
  *
- * Copyright (C) 2001-2003
- *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -20,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -32,13 +30,13 @@
 class gcpElementTool: public gcpTool
 {
 public:
-	gcpElementTool(gcpApplication *App);
-	virtual ~gcpElementTool();
+	gcpElementTool (gcpApplication *App);
+	virtual ~gcpElementTool ();
 
-	virtual bool OnClicked();
-	virtual void OnDrag();
-	virtual void OnRelease();
-	virtual void SetOptions();
+	bool OnClicked ();
+	void OnDrag ();
+	void OnRelease ();
+	char const *GetHelpTag () {return "element";}
 
 private:
 	double m_x2, m_y2;
