@@ -335,7 +335,7 @@ void gcpChainTool::SetLength (double length)
 
 GtkWidget *gcpChainTool::GetPropertyPage ()
 {
-	GladeXML *xml = glade_xml_new (DATADIR"/gchempaint/ui/chain.glade", "chain", GETTEXT_PACKAGE);
+	GladeXML *xml = glade_xml_new (GLADEDIR"/chain.glade", "chain", GETTEXT_PACKAGE);
 	m_LengthBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "bond-length"));
 	g_signal_connect (m_LengthBtn, "value-changed", G_CALLBACK (on_length_changed), this);
 	m_AngleBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "bond-angle"));
